package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.RmSwitchManagement;

/**
 * 交换机管理Mapper接口
 * 
 * @author gyt
 * @date 2025-10-10
 */
public interface RmSwitchManagementMapper 
{
    /**
     * 查询交换机管理
     * 
     * @param id 交换机管理主键
     * @return 交换机管理
     */
    public RmSwitchManagement selectRmSwitchManagementById(Long id);

    /**
     * 查询交换机管理列表
     * 
     * @param rmSwitchManagement 交换机管理
     * @return 交换机管理集合
     */
    public List<RmSwitchManagement> selectRmSwitchManagementList(RmSwitchManagement rmSwitchManagement);

    /**
     * 新增交换机管理
     * 
     * @param rmSwitchManagement 交换机管理
     * @return 结果
     */
    public int insertRmSwitchManagement(RmSwitchManagement rmSwitchManagement);

    /**
     * 修改交换机管理
     * 
     * @param rmSwitchManagement 交换机管理
     * @return 结果
     */
    public int updateRmSwitchManagement(RmSwitchManagement rmSwitchManagement);

    /**
     * 删除交换机管理
     * 
     * @param id 交换机管理主键
     * @return 结果
     */
    public int deleteRmSwitchManagementById(Long id);

    /**
     * 批量删除交换机管理
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteRmSwitchManagementByIds(Long[] ids);
}
